@@ -1,6 +1,7 @@
-use yazi_shared::{emit, event::Cmd, render, Layer};
+use yazi_proxy::InputProxy;
+use yazi_shared::{event::Cmd, render};
 
-use crate::{completion::Completion, input::Input};
+use crate::completion::Completion;
 
 pub struct Opt {
 	submit: bool,
@@ -11,16 +12,11 @@ impl From<Cmd> for Opt {
 }
 
 impl Completion {
-	#[inline]
-	pub fn _close() {
-		emit!(Call(Cmd::new("close"), Layer::Completion));
-	}
-
 	pub fn close(&mut self, opt: impl Into<Opt>) {
 		let opt = opt.into() as Opt;
 
 		if let Some(s) = self.selected().filter(|_| opt.submit) {
-			Input::_complete(s, self.ticket);
+			InputProxy::complete(s, self.ticket);
 		}
 
 		self.caches.clear();
