@@ -1,4 +1,4 @@
-use yazi_scheduler::Scheduler;
+use yazi_proxy::AppProxy;
 use yazi_shared::event::Cmd;
 
 use crate::manager::Manager;
@@ -7,7 +7,7 @@ impl Manager {
 	pub fn suspend(&mut self, _: Cmd) {
 		#[cfg(unix)]
 		tokio::spawn(async move {
-			Scheduler::app_stop().await;
+			AppProxy::stop().await;
 			unsafe { libc::raise(libc::SIGTSTP) };
 		});
 	}
