@@ -1,7 +1,10 @@
-use yazi_config::BOOT;
+use std::ops::{Deref, DerefMut};
+
+use yazi_boot::BOOT;
+use yazi_proxy::ManagerProxy;
 use yazi_shared::fs::Url;
 
-use crate::{manager::Manager, tab::Tab};
+use crate::tab::Tab;
 
 pub struct Tabs {
 	pub idx:          usize,
@@ -15,7 +18,7 @@ impl Tabs {
 			tabs.items[0].reveal(Url::from(BOOT.cwd.join(file)));
 		}
 
-		Manager::_refresh();
+		ManagerProxy::refresh();
 		tabs
 	}
 
@@ -40,24 +43,25 @@ impl Tabs {
 		}
 
 		self.idx = idx;
-		Manager::_refresh();
-		Manager::_peek(true);
+		ManagerProxy::refresh();
+		ManagerProxy::peek(true);
 	}
 }
 
 impl Tabs {
-	#[inline]
-	pub fn len(&self) -> usize { self.items.len() }
-
-	#[inline]
-	pub fn iter(&self) -> impl Iterator<Item = &Tab> { self.items.iter() }
-
-	#[inline]
-	pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Tab> { self.items.iter_mut() }
-
 	#[inline]
 	pub fn active(&self) -> &Tab { &self.items[self.idx] }
 
 	#[inline]
 	pub(super) fn active_mut(&mut self) -> &mut Tab { &mut self.items[self.idx] }
 }
+
+impl Deref for Tabs {
+	type Target = Vec<Tab>;
+
+	fn deref(&self) -> &Self::Target { &self.items }
+}
+
+impl DerefMut for Tabs {
+	fn deref_mut(&mut self) -> &mut Self::Target { &mut self.items }
+}
