@@ -1,11 +1,12 @@
 mod arrow;
-mod backstack;
+mod back;
 mod cd;
 mod copy;
 mod enter;
 mod escape;
 mod filter;
 mod find;
+mod forward;
 mod hidden;
 mod jump;
 mod leave;
@@ -14,6 +15,7 @@ mod preview;
 mod reveal;
 mod search;
 mod select;
+mod select_all;
 mod shell;
 mod sort;
 mod visual_mode;
