@@ -1,10 +1,11 @@
 use yazi_config::{open::Opener, popup::InputCfg};
+use yazi_proxy::{InputProxy, TasksProxy};
 use yazi_shared::event::Cmd;
 
-use crate::{input::Input, tab::Tab, tasks::Tasks};
+use crate::tab::Tab;
 
 pub struct Opt {
-	exec:    String,
+	run:     String,
 	block:   bool,
 	confirm: bool,
 }
@@ -12,7 +13,7 @@ pub struct Opt {
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
 		Self {
-			exec:    c.take_first().unwrap_or_default(),
+			run:     c.take_first().unwrap_or_default(),
 			block:   c.named.contains_key("block"),
 			confirm: c.named.contains_key("confirm"),
 		}
@@ -20,21 +21,25 @@ impl From<Cmd> for Opt {
 }
 
 impl Tab {
-	pub fn shell(&self, opt: impl Into<Opt>) {
+	pub fn shell(&mut self, opt: impl Into<Opt>) {
+		if !self.try_escape_visual() {
+			return;
+		}
+
 		let mut opt = opt.into() as Opt;
-		let selected: Vec<_> = self.selected().into_iter().map(|f| f.url()).collect();
+		let selected = self.hovered_and_selected().into_iter().cloned().collect();
 
 		tokio::spawn(async move {
-			if !opt.confirm || opt.exec.is_empty() {
-				let mut result = Input::_show(InputCfg::shell(opt.block).with_value(opt.exec));
+			if !opt.confirm || opt.run.is_empty() {
+				let mut result = InputProxy::show(InputCfg::shell(opt.block).with_value(opt.run));
 				match result.recv().await {
-					Some(Ok(e)) => opt.exec = e,
+					Some(Ok(e)) => opt.run = e,
 					_ => return,
 				}
 			}
 
-			Tasks::_open(selected, Opener {
-				exec:   opt.exec,
+			TasksProxy::open_with(selected, Opener {
+				run:    opt.run,
 				block:  opt.block,
 				orphan: false,
 				desc:   Default::default(),
