@@ -1,11 +1,11 @@
-use std::{borrow::Cow, collections::BTreeMap};
+use std::collections::HashMap;
 
 use anyhow::Result;
 use tokio::task::JoinHandle;
-use yazi_shared::{fs::{File, Url}, render};
+use yazi_shared::{fs::Url, render};
 
 use super::{Backstack, Config, Finder, Mode, Preview};
-use crate::folder::{Folder, FolderStage};
+use crate::{folder::{Folder, FolderStage}, tab::Selected};
 
 pub struct Tab {
 	pub mode:    Mode,
@@ -14,7 +14,8 @@ pub struct Tab {
 	pub parent:  Option<Folder>,
 
 	pub backstack: Backstack<Url>,
-	pub history:   BTreeMap<Url, Folder>,
+	pub history:   HashMap<Url, Folder>,
+	pub selected:  Selected,
 
 	pub preview:       Preview,
 	pub finder:        Option<Finder>,
@@ -32,6 +33,7 @@ impl From<Url> for Tab {
 
 			backstack: Backstack::new(url),
 			history: Default::default(),
+			selected: Default::default(),
 
 			preview: Default::default(),
 			finder: None,
@@ -47,31 +49,38 @@ impl From<&Url> for Tab {
 }
 
 impl Tab {
-	// --- Mode
-	#[inline]
-	pub fn in_selecting(&self) -> bool { self.mode.is_visual() || self.current.files.has_selected() }
-
 	// --- Current
-	pub fn selected(&self) -> Vec<&File> {
-		let pending = self.mode.visual().map(|(_, p)| Cow::Borrowed(p)).unwrap_or_default();
-		let selected = self.current.files.selected(&pending, self.mode.is_unset());
-
-		if selected.is_empty() {
-			self.current.hovered().map(|h| vec![h]).unwrap_or_default()
+	pub fn selected_or_hovered(&self) -> Vec<&Url> {
+		if self.selected.is_empty() {
+			self.current.hovered().map(|h| vec![&h.url]).unwrap_or_default()
 		} else {
-			selected
+			self.selected.iter().collect()
+		}
+	}
+
+	pub fn hovered_and_selected(&self) -> Vec<&Url> {
+		let Some(h) = self.current.hovered() else {
+			return vec![];
+		};
+
+		if self.selected.is_empty() {
+			vec![&h.url, &h.url]
+		} else {
+			[&h.url].into_iter().chain(self.selected.iter()).collect()
 		}
 	}
 
 	// --- History
-	#[inline]
-	pub fn history(&self, url: &Url) -> Option<&Folder> { self.history.get(url) }
-
 	#[inline]
 	pub fn history_new(&mut self, url: &Url) -> Folder {
 		self.history.remove(url).unwrap_or_else(|| Folder::from(url))
 	}
 
+	#[inline]
+	pub fn hovered_folder(&self) -> Option<&Folder> {
+		self.current.hovered().filter(|&h| h.is_dir()).and_then(|h| self.history.get(&h.url))
+	}
+
 	pub fn apply_files_attrs(&mut self) {
 		let apply = |f: &mut Folder| {
 			if f.stage == FolderStage::Loading {
