@@ -4,13 +4,13 @@ use crate::tasks::Tasks;
 
 impl Tasks {
 	pub fn cancel(&mut self, _: Cmd) {
-		let id = self.scheduler.running.lock().get_id(self.cursor);
+		let id = self.scheduler.ongoing.lock().get_id(self.cursor);
 		if id.map(|id| self.scheduler.cancel(id)) != Some(true) {
 			return;
 		}
 
-		let len = self.scheduler.running.lock().len();
-		self.cursor = self.cursor.min(len.saturating_sub(1));
+		self.summaries = self.paginate();
+		self.arrow(0);
 		render!();
 	}
 }
