@@ -34,8 +34,10 @@ impl<'a> Executor<'a> {
 			};
 		}
 
+		on!(notify);
 		on!(plugin);
 		on!(plugin_do);
+		on!(update_notify);
 		on!(update_progress);
 		on!(resize);
 		on!(stop);
@@ -96,6 +98,7 @@ impl<'a> Executor<'a> {
 		on!(MANAGER, paste, &self.app.cx.tasks);
 		on!(MANAGER, link, &self.app.cx.tasks);
 		on!(MANAGER, remove, &self.app.cx.tasks);
+		on!(MANAGER, remove_do, &self.app.cx.tasks);
 		on!(MANAGER, create);
 		on!(MANAGER, rename);
 		on!(ACTIVE, copy);
@@ -148,11 +151,11 @@ impl<'a> Executor<'a> {
 			};
 		}
 
-		on!(open);
 		on!(toggle, "close");
 		on!(arrow);
 		on!(inspect);
 		on!(cancel);
+		on!(open_with);
 
 		#[allow(clippy::single_match)]
 		match cmd.name.as_str() {
