@@ -1,7 +1,7 @@
 #![allow(clippy::module_inception)]
 #![allow(clippy::unit_arg)]
 
-#[cfg(unix)]
+#[cfg(all(not(target_os = "macos"), not(target_os = "windows")))]
 #[global_allocator]
 static GLOBAL: tikv_jemallocator::Jemalloc = tikv_jemallocator::Jemalloc;
 
@@ -14,6 +14,7 @@ mod help;
 mod input;
 mod lives;
 mod logs;
+mod notify;
 mod panic;
 mod root;
 mod router;
@@ -21,7 +22,6 @@ mod select;
 mod signals;
 mod tasks;
 mod which;
-mod widgets;
 
 use context::*;
 use executor::*;
@@ -34,18 +34,22 @@ use signals::*;
 
 #[tokio::main]
 async fn main() -> anyhow::Result<()> {
+	Panic::install();
+	Logs::start();
+
 	_ = fdlimit::raise_fd_limit();
-	// console_subscriber::init();
 
 	yazi_config::init();
 
-	yazi_core::init();
+	yazi_adaptor::init();
 
-	yazi_scheduler::init();
+	yazi_boot::init();
 
 	yazi_plugin::init();
 
-	yazi_adaptor::init();
+	yazi_proxy::init();
 
-	app::App::run().await
+	yazi_core::init();
+
+	app::App::serve().await
 }
