@@ -29,17 +29,16 @@ function ya.flat(t)
 end
 
 function ya.sync(f)
-	ya.SYNC_CALLS = ya.SYNC_CALLS + 1
-	if ya.SYNC_BLOCK == ya.SYNC_CALLS then
-		ya.SYNC_ENTRY = f
+	YAZI_SYNC_CALLS = YAZI_SYNC_CALLS + 1
+
+	local name, calls = YAZI_PLUGIN_NAME, YAZI_SYNC_CALLS
+	if not YAZI_SYNC_BLOCKS then
+		return function(...) return ya.plugin_retrieve(name, calls, ...) end
 	end
 
-	if ya.SYNC_ON then
-		return f
-	end
-
-	local calls = ya.SYNC_CALLS
-	return function(...) return plugin_retrieve(YAZI_PLUGIN_NAME, calls, ...) end
+	YAZI_SYNC_BLOCKS[name] = YAZI_SYNC_BLOCKS[name] or {}
+	YAZI_SYNC_BLOCKS[name][calls] = f
+	return function(...) return f(package.loaded[name], ...) end
 end
 
 function ya.basename(str) return string.gsub(str, "(.*[/\\])(.*)", "%2") end
@@ -56,7 +55,7 @@ end
 
 function ya.readable_path(path)
 	local home = os.getenv("HOME") or os.getenv("USERPROFILE")
-	if home == nil then
+	if not home then
 		return path
 	elseif string.sub(path, 1, #home) == home then
 		return "~" .. string.sub(path, #home + 1)
