@@ -4,17 +4,18 @@ mod bindings;
 mod cha;
 mod file;
 mod icon;
+mod input;
+mod permit;
+mod position;
 mod range;
 mod window;
 
-#[allow(unused_imports)]
 pub use bindings::*;
 pub use cha::*;
 pub use file::*;
 pub use icon::*;
+pub use input::*;
+pub use permit::*;
+pub use position::*;
 pub use range::*;
 pub use window::*;
-
-pub trait Cast<T> {
-	fn cast(lua: &mlua::Lua, data: T) -> mlua::Result<mlua::AnyUserData>;
-}
