@@ -17,7 +17,7 @@ pub fn peek(cmd: &Cmd, file: yazi_shared::fs::File, skip: usize) -> Cancellation
 		let future = async {
 			LOADED.ensure(&name).await.into_lua_err()?;
 
-			let lua = slim_lua()?;
+			let lua = slim_lua(&name)?;
 			lua.set_hook(
 				HookTriggers::new().on_calls().on_returns().every_nth_instruction(2000),
 				move |_, _| {
@@ -30,10 +30,10 @@ pub fn peek(cmd: &Cmd, file: yazi_shared::fs::File, skip: usize) -> Cancellation
 			} else {
 				return Err("unloaded plugin".into_lua_err());
 			};
-			plugin.set("file", File::cast(&lua, file)?)?;
-			plugin.set("skip", skip)?;
-			plugin.set("area", Rect::cast(&lua, LAYOUT.load().preview)?)?;
-			plugin.set("window", Window::default())?;
+			plugin.raw_set("file", File::cast(&lua, file)?)?;
+			plugin.raw_set("skip", skip)?;
+			plugin.raw_set("area", Rect::cast(&lua, LAYOUT.load().preview)?)?;
+			plugin.raw_set("window", Window::default())?;
 
 			if ct2.is_cancelled() { Ok(()) } else { plugin.call_async_method("peek", ()).await }
 		};
@@ -57,15 +57,14 @@ pub fn peek(cmd: &Cmd, file: yazi_shared::fs::File, skip: usize) -> Cancellation
 
 pub fn peek_sync(cmd: &Cmd, file: yazi_shared::fs::File, skip: usize) {
 	let data = OptData {
-		args: vec![],
-		cb:   Some(Box::new(move |plugin| {
-			plugin.set("file", File::cast(&LUA, file)?)?;
-			plugin.set("skip", skip)?;
-			plugin.set("area", Rect::cast(&LUA, LAYOUT.load().preview)?)?;
-			plugin.set("window", Window::default())?;
+		cb: Some(Box::new(move |_, plugin| {
+			plugin.raw_set("file", File::cast(&LUA, file)?)?;
+			plugin.raw_set("skip", skip)?;
+			plugin.raw_set("area", Rect::cast(&LUA, LAYOUT.load().preview)?)?;
+			plugin.raw_set("window", Window::default())?;
 			plugin.call_method("peek", ())
 		})),
-		tx:   None,
+		..Default::default()
 	};
 	emit!(Call(
 		Cmd::args("plugin", vec![cmd.name.to_owned()]).with_bool("sync", true).with_data(data),
