@@ -6,7 +6,7 @@ use crate::{elements::RectRef, url::UrlRef};
 
 impl Utils {
 	pub(super) fn image(lua: &Lua, ya: &Table) -> mlua::Result<()> {
-		ya.set(
+		ya.raw_set(
 			"image_show",
 			lua.create_async_function(|lua, (url, rect): (UrlRef, RectRef)| async move {
 				if let Ok(size) = ADAPTOR.image_show(&url, *rect).await {
@@ -17,7 +17,7 @@ impl Utils {
 			})?,
 		)?;
 
-		ya.set(
+		ya.raw_set(
 			"image_precache",
 			lua.create_async_function(|_, (src, dist): (UrlRef, UrlRef)| async move {
 				Ok(Image::precache(&src, dist.to_path_buf()).await.is_ok())
