@@ -5,9 +5,9 @@ use super::Utils;
 
 impl Utils {
 	pub(super) fn log(lua: &Lua, ya: &Table) -> mlua::Result<()> {
-		ya.set("dbg", lua.create_function(|_, s: String| Ok(debug!("{s}")))?)?;
+		ya.raw_set("dbg", lua.create_function(|_, s: String| Ok(debug!("{s}")))?)?;
 
-		ya.set("err", lua.create_function(|_, s: String| Ok(error!("{s}")))?)?;
+		ya.raw_set("err", lua.create_function(|_, s: String| Ok(error!("{s}")))?)?;
 
 		Ok(())
 	}
