@@ -9,7 +9,6 @@ mod errors;
 pub mod event;
 pub mod fs;
 mod layer;
-mod mime;
 mod natsort;
 mod number;
 mod os;
@@ -17,6 +16,7 @@ mod ro_cell;
 pub mod term;
 mod throttle;
 mod time;
+mod xdg;
 
 pub use chars::*;
 pub use condition::*;
@@ -25,10 +25,10 @@ pub use defer::*;
 pub use env::*;
 pub use errors::*;
 pub use layer::*;
-pub use mime::*;
 pub use natsort::*;
 pub use number::*;
 pub use os::*;
 pub use ro_cell::*;
 pub use throttle::*;
 pub use time::*;
+pub use xdg::*;
